# RelationalAI Documentation

Welcome to the RelationalAI docs!

- 🏃🏽‍♂️ Get up and running fast with our [Getting Started guide](./getting_started.md).
- 🤓 Explore every nook and cranny in the [API reference](./api_reference/) section.
